summaryrefslogtreecommitdiffstats
path: root/models/org.js
diff options
context:
space:
mode:
Diffstat (limited to 'models/org.js')
-rw-r--r--models/org.js10
1 files changed, 5 insertions, 5 deletions
diff --git a/models/org.js b/models/org.js
index 3d41a436..207bfad7 100644
--- a/models/org.js
+++ b/models/org.js
@@ -14,7 +14,7 @@ Org.attachSchema(
// eslint-disable-next-line consistent-return
autoValue() {
if (this.isInsert && !this.isSet) {
- return incrementCounter('counters', 'org_id', 1);
+ return incrementCounter('counters', 'orgId', 1);
}
},
},
@@ -65,9 +65,9 @@ Org.attachSchema(
optional: true,
max: 255,
},
- zip_code: {
+ zipCode: {
/**
* zip_code of the organization
*/
type: String,
optional: true,
@@ -81,9 +81,9 @@ Org.attachSchema(
optional: true,
max: 255,
},
- billing_email: {
+ billingEmail: {
/**
* billing_email of the organization
*/
type: String,
optional: true,
@@ -65,9 +65,9 @@ Org.attachSchema(
/**
- * zip_code of the organization
+ * zipCode of the organization
*/
type: String,
@@ -81,9 +81,9 @@ Org.attachSchema(
/**
- * billing_email of the organization
+ * billingEmail of the organization
*/
type: String,